==> laravel-echo-1.1.15.tgz: package/lib/plugin.js <==
import Echo from 'laravel-echo'

<% if (options.broadcaster === 'pusher') { %>
window.Pusher = require('pusher-js')
<% } else if (options.broadcaster === 'socket.io') { %>
window.io = require('socket.io-client')
<% } %>

function getHeaders ({ app }) {
  const headers = {}

  <% if (options.authModule) { %>
  if (app.$auth) {
    const strategy = app.$auth.$storage.state.strategy
    const currentStrategy = app.$auth.strategies[strategy]
    if (currentStrategy) {
      const tokenName = currentStrategy.options.token.name || 'Authorization'
      const token = currentStrategy.token.get()

      if (token) {
        headers[tokenName] = token
      }
    }
  }
  <% } %>

  return headers
}

export default (ctx, inject) => {
  const options = <%= serialize(options) %>
  options.auth = options.auth || {}
  options.auth.headers = {
    ...options.auth.headers,
    ...getHeaders(ctx)
  }

  const echo = new Echo(options)

  if(options.debug) {
    echo.connector.socket.on('connect', function(){
        console.log('connected', echo.socketId());
    });
    echo.connector.socket.on('disconnect', function(){
        console.log('disconnected');
    });
    echo.connector.socket.on('reconnecting', function(attemptNumber){
        console.log('reconnecting', attemptNumber);
    });
  }

  <% if (options.authModule) { %>
  if (ctx.app.$auth) {
    ctx.app.$auth.$storage.watchState('loggedIn', loggedIn => {
      echo.options.auth.headers = {
        ...echo.options.auth.headers,
        ...getHeaders(ctx)
      }

      <% if (options.connectOnLogin) { %>
      if (loggedIn) {
        echo.connect()
        if (options.debug) {
          console.log('I am connected beacause login called')
        }
      }
      <% } %>

      <% if (options.disconnectOnLogout) { %>
      if (!loggedIn && echo.connector) {
        echo.disconnect()
        if (options.debug) {
          console.log('I am disconnected beacause logged out called')
        }
      }
      <% } %>
    })
  }
  <% } %>

  ctx.$echo = echo
  inject('echo', echo)
}

==> laravel-echo-1.1.16.tgz: package/lib/plugin.js <==
import Echo from 'laravel-echo'

<% if (options.broadcaster === 'pusher') { %>
window.Pusher = require('pusher-js')
<% } else if (options.broadcaster === 'socket.io') { %>
window.io = require('socket.io-client')
<% } %>

function getHeaders ({ app }) {
  const headers = {}

  <% if (options.authModule) { %>
  if (app.$auth) {
    const strategy = app.$auth.$storage.state.strategy
    const currentStrategy = app.$auth.strategies[strategy]
    if (currentStrategy) {
      const tokenName = currentStrategy.options.token.name || 'Authorization'
      const token = currentStrategy.token.get()

      if (token) {
        headers[tokenName] = token
      }
    }
  }
  <% } %>

  return headers
}

export default (ctx, inject) => {
  const options = <%= serialize(options) %>
  options.auth = options.auth || {}
  options.auth.headers = {
    ...options.auth.headers,
    ...getHeaders(ctx)
  }

  const echo = new Echo(options)

  if(options.debug) {
    echo.connector.socket.on('connect', function(){
        console.log('[Laravel Echo] connected', echo.socketId());
    });
    echo.connector.socket.on('disconnect', function(){
        console.log('[Laravel Echo] disconnected');
    });
    echo.connector.socket.on('reconnecting', function(attemptNumber){
        console.log('[Laravel Echo] reconnecting', attemptNumber);
    });
  }

  <% if (options.authModule) { %>
  if (ctx.app.$auth) {
    ctx.app.$auth.$storage.watchState('loggedIn', loggedIn => {
      echo.options.auth.headers = {
        ...echo.options.auth.headers,
        ...getHeaders(ctx)
      }

      if (options.debug) {
          console.log('[Laravel Echo] options:', options)
      }

      <% if (options.connectOnLogin) { %>
      if (loggedIn) {
        echo.connect()
        if (options.debug) {
          console.log('[Laravel Echo] I am connected beacause login called')
        }
      }
      <% } %>

      <% if (options.disconnectOnLogout) { %>
      if (!loggedIn && echo.connector) {
        echo.disconnect()
        if (options.debug) {
          console.log('[Laravel Echo] I am disconnected beacause logged out called')
        }
      }
      <% } %>
    })
  }
  <% } %>

  ctx.$echo = echo
  inject('echo', echo)
}
